@@ -1,5 +1,5 @@
-#  tests for ephem-4.1-py37h179b583_0 (this is a generated file);
-print('===== testing package: ephem-4.1-py37h179b583_0 =====');
+#  tests for ephem-4.1.3-py37h179b583_3 (this is a generated file);
+print('===== testing package: ephem-4.1.3-py37h179b583_3 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import ephem
@@ -10,7 +10,7 @@ assert str(mars.ra) == '5:59:27.35'
 assert str(mars.dec) == '26:56:27.4'
 #  --- run_test.py (end) ---
 
-print('===== ephem-4.1-py37h179b583_0 OK =====');
+print('===== ephem-4.1.3-py37h179b583_3 OK =====');
 print("import: 'ephem'")
 import ephem
 
